@@ -1,12 +1,10 @@
 //! Indeterminate offset
 
-use core::convert::TryFrom;
 use core::fmt;
 
 use crate::error;
 
 /// The system's UTC offset could not be determined at the given datetime.
-#[cfg_attr(__time_03_docs, doc(cfg(feature = "local-offset")))]
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
 pub struct IndeterminateOffset;
 
@@ -17,16 +15,15 @@ impl fmt::Display for IndeterminateOffset {
 }
 
 #[cfg(feature = "std")]
+#[allow(clippy::std_instead_of_core)]
 impl std::error::Error for IndeterminateOffset {}
 
-#[cfg_attr(__time_03_docs, doc(cfg(feature = "local-offset")))]
 impl From<IndeterminateOffset> for crate::Error {
     fn from(err: IndeterminateOffset) -> Self {
         Self::IndeterminateOffset(err)
     }
 }
 
-#[cfg_attr(__time_03_docs, doc(cfg(feature = "std")))]
 impl TryFrom<crate::Error> for IndeterminateOffset {
     type Error = error::DifferentVariant;
 
