@@ -7,12 +7,7 @@ use crate::{Date, Duration, Month, OffsetDateTime, PrimitiveDateTime, Time, UtcO
 
 impl Distribution<Time> for Standard {
     fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> Time {
-        Time::__from_hms_nanos_unchecked(
-            rng.gen_range(0..24),
-            rng.gen_range(0..60),
-            rng.gen_range(0..60),
-            rng.gen_range(0..1_000_000_000),
-        )
+        Time::from_hms_nanos_ranged(rng.r#gen(), rng.r#gen(), rng.r#gen(), rng.r#gen())
     }
 }
 
@@ -26,12 +21,7 @@ impl Distribution<Date> for Standard {
 
 impl Distribution<UtcOffset> for Standard {
     fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> UtcOffset {
-        let seconds = rng.gen_range(-86399..=86399);
-        UtcOffset::__from_hms_unchecked(
-            (seconds / 3600) as _,
-            ((seconds % 3600) / 60) as _,
-            (seconds % 60) as _,
-        )
+        UtcOffset::from_hms_ranged(rng.r#gen(), rng.r#gen(), rng.r#gen())
     }
 }
 
@@ -50,9 +40,7 @@ impl Distribution<OffsetDateTime> for Standard {
 
 impl Distribution<Duration> for Standard {
     fn sample<R: Rng + ?Sized>(&self, rng: &mut R) -> Duration {
-        Duration::nanoseconds_i128(
-            rng.gen_range(Duration::MIN.whole_nanoseconds()..=Duration::MAX.whole_nanoseconds()),
-        )
+        Duration::new_ranged(rng.r#gen(), rng.r#gen())
     }
 }
 
@@ -67,7 +55,10 @@ impl Distribution<Weekday> for Standard {
             3 => Thursday,
             4 => Friday,
             5 => Saturday,
-            _ => Sunday,
+            val => {
+                debug_assert!(val == 6);
+                Sunday
+            }
         }
     }
 }
@@ -87,7 +78,10 @@ impl Distribution<Month> for Standard {
             9 => September,
             10 => October,
             11 => November,
-            _ => December,
+            val => {
+                debug_assert!(val == 12);
+                December
+            }
         }
     }
 }
